
/* Generated data (by glib-mkenums) */

#ifndef __LIBEMPATHY_GTK_ENUM_TYPES_H__
#define __LIBEMPATHY_GTK_ENUM_TYPES_H__ 1

#include <glib-object.h>

G_BEGIN_DECLS

#include <libempathy-gtk/empathy-contact-list-store.h>
#define EMPATHY_TYPE_CONTACT_LIST_STORE_SORT empathy_contact_list_store_sort_get_type()
GType empathy_contact_list_store_sort_get_type (void);
#define EMPATHY_TYPE_CONTACT_LIST_STORE_COL empathy_contact_list_store_col_get_type()
GType empathy_contact_list_store_col_get_type (void);
#include <libempathy-gtk/empathy-contact-list-view.h>
#define EMPATHY_TYPE_CONTACT_LIST_FEATURE_FLAGS empathy_contact_list_feature_flags_get_type()
GType empathy_contact_list_feature_flags_get_type (void);
#include <libempathy-gtk/empathy-contact-menu.h>
#define EMPATHY_TYPE_CONTACT_FEATURE_FLAGS empathy_contact_feature_flags_get_type()
GType empathy_contact_feature_flags_get_type (void);
#include <libempathy-gtk/empathy-contact-widget.h>
#define EMPATHY_TYPE_CONTACT_WIDGET_FLAGS empathy_contact_widget_flags_get_type()
GType empathy_contact_widget_flags_get_type (void);
#include <libempathy-gtk/empathy-ui-utils.h>
#define EMPATHY_TYPE_SOUND empathy_sound_get_type()
GType empathy_sound_get_type (void);
G_END_DECLS

#endif /* __LIBEMPATHY_GTK_ENUM_TYPES_H__ */

/* Generated data ends here */

